#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
import argparse
import sys
import textwrap

# import interfaces

# import packages
from pyams_content_es.site import site_index
from pyramid.paster import bootstrap


def index_site():
    """Update all ElasticSearch indexes"""
    usage = "usage: {0} config_uri".format(sys.argv[0])
    description = """Update all ElasticSearch indexes with all database contents."""

    parser = argparse.ArgumentParser(usage=usage,
                                     description=textwrap.dedent(description))
    parser.add_argument('-i', '--include', action='append',
                        help="Include only this shared contents")
    parser.add_argument('-x', '--exclude', action='append',
                        help="Exclude this shared contents")
    parser.add_argument('config_uri', help='Name of configuration file')
    args = parser.parse_args()

    if args.include and args.exclude:
        print("INCLUDE and EXCLUDE arguments can't be used together!")
        sys.exit(1)

    env = bootstrap(args.config_uri)
    settings, closer = env['registry'].settings, env['closer']
    try:
        site_index(env['request'], include=args.include, exclude=args.exclude)
    finally:
        closer()
